@@ -10,11 +10,19 @@ logger = logging.getLogger(__name__)
 
 
 class DiscourseError(HTTPError):
-    """ A generic error while attempting to communicate with Discourse """
+    pass
 
 
 class DiscourseClientError(DiscourseError):
-    """ An invalid request has been made """
+    pass
+
+
+class DiscourseClientNotFound(DiscourseError):
+    pass
+
+
+class DiscourseClientForbidden(DiscourseError):
+    pass
 
 
 DELETE = "DELETE"
@@ -62,14 +70,16 @@ class DiscourseClient(object):
             headers=headers,
         )
 
+        request_message = f"request {verb} {url} params={params} data={data}"
+        logger.debug(request_message)
         response = requests.request(verb, url, **request_kwargs)
+        logger.debug(f"response {response.status_code}: {repr(response.text[:400])}")
 
-        logger.debug("response %s:%s: %s", response.status_code,
-                     response.headers["content-type"], repr(response.text[:400]))
-
-        if response.status_code == 302:
-            raise DiscourseError(
-                "Unexpected Redirect, invalid api key or host?", response=response)
+        if response.status_code == 404:
+            raise DiscourseClientNotFound(request_message)
+        elif response.status_code == 403:
+            raise DiscourseClientForbidden(request_message)
+        response.raise_for_status()
 
         if not response.content.strip():
             return None
@@ -268,7 +278,7 @@ class Discourse(object):
         try:
             category = self.d._get(f'/c/{slug}/show.json')['category']
             return self.category_dict2params(category)
-        except DiscourseClientError:
+        except DiscourseClientNotFound:
             return None
 
     def category_create(self, name):
@@ -423,7 +433,7 @@ class Discourse(object):
         try:
             group = self.d._get(f'/groups/{name}.json')
             return self.group_dict2params(group)
-        except DiscourseClientError:
+        except DiscourseClientNotFound:
             return None
 
     def group_create(self, name, **kwargs):
@@ -531,7 +541,7 @@ class Discourse(object):
         try:
             user = self.d._get(f'/users/{username}.json')
             return self.user_dict2params(user['user'])
-        except DiscourseClientError:
+        except DiscourseClientNotFound:
             return None
 
     def user_get(self, email):
